==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>プラグイン %1 はこのシステムと互換性がありません。</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth設定</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>オフにする</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>オンにする</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth設定</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1が接続されました</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>接続試行中...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>オフにしました</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>キーボードレイアウトを追加</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>日時</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12時間表示</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24時間表示</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>時間設定</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>ネットワークを有効にする</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>ネットワークを無効にする</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>ネットワーク設定</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>%1 項目を空にしてもよろしいですか？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>この操作は元に戻せません</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>不明なデバイス</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>不明なボリューム</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>ディスク</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>すべてマウント解除</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>ランチャー</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>ファッションモード</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>エフィシェントモード</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>常に表示</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>常に非表示</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>賢く非表示にする</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>モード</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>状態</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>プラグイン</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>マルチタスク画面</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>ドックから外す</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>有線接続を無効にする</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>有線接続を有効にする</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>無線接続を無効にする</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>無線接続を有効にする</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>ネットワークを無効にする</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>ネットワークを有効にする</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>ネットワーク設定</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>デバイスが無効</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>無線接続: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>有線接続: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未接続</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>接続試行中</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>接続済み、インターネットアクセスなし</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>ネットワークケーブル未接続</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>無線ネットワーク</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有線ネットワーク</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>ネットワーク</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有線ネットワーク</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>有線ネットワーク %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>電源の設定</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>バッテリー残量 %1、残り %2 分</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>バッテリー残量 %1、残り %2 時間 %3 分</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>充電中 %1、充電完了まで %2 分</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>充電中 %1、充電完了まで %2 時間 %3 分</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>充電完了</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>バッテリー残量 %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>充電中 %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>バッテリー残量 %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>バッテリー残量 %1、フル充電済み</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>デスクトップを表示</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>ドックから外す</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>シャットダウン</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>サスペンド</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>ハイバーネート</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>ロック</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>ログアウト</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>アカウントを切り替え</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>電源の設定</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>再起動</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>デバイス</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>消音を解除</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>消音</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>サウンドの設定</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>音量 %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>サウンド</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>ゴミ箱</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>ゴミ箱 - %1 ファイル</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>ゴミ箱 - %1 ファイル</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>空</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>システムトレイ</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>無線ネットワーク</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>無線接続 %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.78.orig.tar.xz: dde-dock-5.5.78/translations/dde-dock_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>プラグイン %1 はこのシステムと互換性がありません。</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>オフにする</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>オンにする</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth設定</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>オフにする</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>オンにする</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth設定</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1が接続されました</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>接続試行中...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>オフにしました</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>キーボードレイアウトを追加</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>日時</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12時間表示</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24時間表示</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>時間設定</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>%1 項目を空にしてもよろしいですか？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>この操作は元に戻せません</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>不明なデバイス</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>不明なボリューム</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>ディスク</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>すべてマウント解除</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>ランチャー</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>ファッションモード</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>エフィシェントモード</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>常に表示</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>常に非表示</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>賢く非表示にする</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>モード</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>状態</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>マルチディスプレイ</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>ファッションモード</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>効率モード</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>モード</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>隠したままにする</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>スマートハイド</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>状態</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>小</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>大</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>マルチタスク画面</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>ドックから外す</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>電源の設定</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>バッテリー残量 %1、残り %2 分</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>バッテリー残量 %1、残り %2 時間 %3 分</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>充電中 %1、充電完了まで %2 分</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>充電中 %1、充電完了まで %2 時間 %3 分</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>バッテリー残量 %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>充電中 %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>バッテリー残量 %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>バッテリー残量 %1、フル充電済み</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>ドック</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>デスクトップを表示</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>ドックから外す</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>シャットダウン</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>サスペンド</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>ハイバーネート</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>ロック</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>ログアウト</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>アカウントを切り替え</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>電源の設定</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>再起動</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>デバイス</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>消音を解除</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>消音</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>サウンドの設定</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>音量 %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>サウンド</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>ゴミ箱</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>ゴミ箱 - %1 ファイル</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>ゴミ箱 - %1 ファイル</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>ゴミ箱へ移動</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>空</translation>
    </message>
</context>
</TS>
